pub struct NamedMatch {
pub name: Option<String>,
pub value: String,
pub span: MatchSpan,
}Expand description
A matched string value paired with an optional name and span.
Fields
name: Option<String>value: Stringspan: MatchSpanTrait Implementations
Sourceimpl Clone for NamedMatch
impl Clone for NamedMatch
Sourcefn clone(&self) -> NamedMatch
fn clone(&self) -> NamedMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NamedMatch
impl Debug for NamedMatch
Sourceimpl Default for NamedMatch
impl Default for NamedMatch
Sourcefn default() -> NamedMatch
fn default() -> NamedMatch
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for NamedMatch
impl PartialEq for NamedMatch
Sourcefn eq(&self, other: &NamedMatch) -> bool
fn eq(&self, other: &NamedMatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for NamedMatch
impl StructuralPartialEq for NamedMatch